/***************************************************************************
                    job_queryplaylist_tracks.h  -  description
                             -------------------
    begin                : Wed May 9 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 
    Contributed by Tim Lee ;-)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_QUERYPLAYLIST_TRACKS_H
#define JOB_QUERYPLAYLIST_TRACKS_H

#include "prokyon.h"

#include "jobbase.h"

class Job_QueryPlaylist_Tracks : public JobBase  {
public:
    Job_QueryPlaylist_Tracks(int _id);

    int type() {
        return JOB_QUERY_PLAYLIST_TRACKS;
    }

    void run();

    ~Job_QueryPlaylist_Tracks();

private:
    int id;
};

#endif
